# A simple wrapper around asyncpg

apgw is a simple wrapper around the excellent asyncpg library. It is designed to make building
certain types of simple queries very easy.

Please note: documentation on this project is currently not provided

## Running tests:

`python -m tests`
